@@ -27,16 +27,13 @@
 #include <QFileDialog>
 #include <QIcon>
 #include <QInputDialog>
-#include <QKeySequence>
 #include <QLabel>
-#include <QMenuBar>
 #include <QPixmapCache>
 #include <QShortcut>
 #include <QStatusBar>
 #include <QWindowStateChangeEvent>
 
 // KDE
-#include <KAboutData>
 #include <KActionCollection>
 #include <KConfigDialog>
 #include <KGameClock>
@@ -45,7 +42,6 @@
 #include <KScoreDialog>
 #include <KStandardAction>
 #include <KStandardGameAction>
-#include <KToggleAction>
 
 // LibKMahjongg
 #include <kmahjonggconfigdialog.h>
@@ -61,7 +57,7 @@
 #include "prefs.h"
 #include "ui_settings.h"
 
-const QString KMahjongg::gameMagic = "kmahjongg-gamedata";
+const QString KMahjongg::gameMagic = QStringLiteral("kmahjongg-gamedata");
 const int KMahjongg::gameDataVersion = 1;
 
 /**
@@ -169,6 +165,10 @@ void KMahjongg::setupKAction()
     actionCollection()->setDefaultShortcut(anglecw, Qt::Key_G);
     connect(anglecw, &QAction::triggered, m_gameView, &GameView::angleSwitchCW);
 
+    m_fullscreenAction = KStandardAction::fullScreen(
+        this, &KMahjongg::toggleFullscreen, this, actionCollection()
+    );
+
     m_demoAction = KStandardGameAction::demo(this, SLOT(demoMode()), actionCollection());
 
     KStandardGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
@@ -188,6 +188,15 @@ void KMahjongg::setupKAction()
     setupGUI(qApp->desktop()->availableGeometry().size() * 0.7);
 }
 
+void KMahjongg::toggleFullscreen(bool fullscreen)
+{
+    if (fullscreen) {
+        setWindowState(Qt::WindowState::WindowFullScreen);
+    } else {
+        setWindowState(Qt::WindowState::WindowNoState);
+    }
+}
+
 void KMahjongg::setupStatusBar()
 {
     m_gameTimerLabel = new QLabel(i18n("Time: 0:00:00"), statusBar());
@@ -303,6 +312,9 @@ void KMahjongg::loadSettings()
         qCDebug(KMAHJONGG_LOG) << "An error occurred when loading the background " << Prefs::background() << " KMahjongg will continue with the default background.";
     }
 
+    // Set wether removed tiles should be shown.
+    m_gameView->showRemovedTiles(Prefs::removedTiles());
+
     // Maybe load a new layout and start a new game if the layout or random mode has changed.
     if (m_boardLayout->path() != Prefs::layout() || m_bLastRandomSetting != Prefs::randomLayout()) {
         // The boardlayout path will likely not be the same as the preference setting if
@@ -362,7 +374,7 @@ void KMahjongg::pause()
 void KMahjongg::showHighscores()
 {
     KScoreDialog ksdialog(KScoreDialog::Name | KScoreDialog::Time, this);
-    const QString layoutName = m_boardLayout->authorProperty("Name");
+    const QString layoutName = m_boardLayout->authorProperty(QStringLiteral("Name"));
     ksdialog.setConfigGroup(qMakePair(QByteArray(layoutName.toUtf8()), layoutName));
     ksdialog.exec();
 }
@@ -500,7 +512,7 @@ void KMahjongg::gameOver(unsigned short numRemoved, unsigned short cheats)
     //long gameNum = m_pGameView->getGameNumber();
     //theHighScores->checkHighScore(score, elapsed, gameNum, m_pGameView->getBoardName());
     QPointer<KScoreDialog> ksdialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Time, this);
-    const QString layoutName = m_boardLayout->authorProperty("Name");
+    const QString layoutName = m_boardLayout->authorProperty(QStringLiteral("Name"));
     ksdialog->setConfigGroup(qMakePair(QByteArray(layoutName.toUtf8()), layoutName));
     KScoreDialog::FieldInfo scoreInfo;
     scoreInfo[KScoreDialog::Score].setNum(score);
@@ -533,19 +545,19 @@ void KMahjongg::updateState(GameState state)
     // KXMLGUIClient::stateChanged() sets action-states def. by kmahjonggui.rc.
     switch (state) {
         case GameState::Demo:
-            stateChanged("demo_state");
+            stateChanged(QStringLiteral("demo_state"));
             break;
         case GameState::Paused:
-            stateChanged("paused_state");
+            stateChanged(QStringLiteral("paused_state"));
             break;
         case GameState::Finished:
-            stateChanged("finished_state");
+            stateChanged(QStringLiteral("finished_state"));
             break;
         case GameState::Stuck:
-            stateChanged("stuck_state");
+            stateChanged(QStringLiteral("stuck_state"));
             break;
         default:
-            stateChanged("gameplay_state");
+            stateChanged(QStringLiteral("gameplay_state"));
             updateUndoAndRedoStates();
             break;
     }
